package cn.com.infosec.jce;

import cn.com.infosec.util.Strings;
import java.security.BasicPermission;
import java.security.Permission;
import java.util.StringTokenizer;

public class ProviderConfigurationPermission extends BasicPermission {
   private static final int THREAD_LOCAL_EC_IMPLICITLY_CA = 1;
   private static final int EC_IMPLICITLY_CA = 2;
   private static final int ALL = 3;
   private static final String THREAD_LOCAL_EC_IMPLICITLY_CA_STR = "threadlocalecimplicitlyca";
   private static final String EC_IMPLICITLY_CA_STR = "ecimplicitlyca";
   private static final String ALL_STR = "all";
   private final String actions;
   private final int permissionMask;

   public ProviderConfigurationPermission(String name) {
      super(name);
      this.actions = "all";
      this.permissionMask = 3;
   }

   public ProviderConfigurationPermission(String name, String actions) {
      super(name, actions);
      this.actions = actions;
      this.permissionMask = this.calculateMask(actions);
   }

   private int calculateMask(String actions) {
      StringTokenizer var3;
      var3 = new StringTokenizer.<init>(Strings.toLowerCase(actions), " ,");
      int actions1 = 0;

      while(var3.hasMoreTokens()) {
         String var2;
         if ((var2 = var3.nextToken()).equals("threadlocalecimplicitlyca")) {
            actions1 |= 1;
         } else if (var2.equals("ecimplicitlyca")) {
            actions1 |= 2;
         } else if (var2.equals("all")) {
            actions1 |= 3;
         }
      }

      if (actions1 != 0) {
         return actions1;
      } else {
         throw new IllegalArgumentException("unknown permissions passed to mask");
      }
   }

   public String getActions() {
      return this.actions;
   }

   public boolean implies(Permission permission) {
      if (!(permission instanceof ProviderConfigurationPermission)) {
         return false;
      } else if (!this.getName().equals(permission.getName())) {
         return false;
      } else {
         ProviderConfigurationPermission var10000 = this;
         ProviderConfigurationPermission var2 = (ProviderConfigurationPermission)permission;
         int var3;
         return (var10000.permissionMask & (var3 = var2.permissionMask)) == var3;
      }
   }

   public boolean equals(Object obj) {
      if (obj == this) {
         return true;
      } else if (obj instanceof ProviderConfigurationPermission) {
         ProviderConfigurationPermission obj1 = (ProviderConfigurationPermission)obj;
         return this.permissionMask == obj1.permissionMask && this.getName().equals(obj1.getName());
      } else {
         return false;
      }
   }

   public int hashCode() {
      return this.getName().hashCode() + this.permissionMask;
   }
}
